@@ -217,14 +217,18 @@ def remove(files):
 def mkdirs(pathname):
     """
     mkdirs - create a folder
+    mkdirs("hello/world)
+    mkdirs("hello/world/file.tif) #file.tif must exists
     """
-    try:
-        if file(pathname):
-            pathname = justpath(pathname)
-        os.makedirs(pathname)
-    except:
-        pass
-    return directory(pathname)
+    if not os.path.isdir(pathname):
+        try:
+            if os.path.isfile(pathname):
+                pathname = justpath(pathname)
+            os.makedirs(pathname)
+        except:
+            pass
+        return os.path.isdir(pathname)
+    return True
 
 def chdir(pathname):
     """
@@ -389,19 +393,20 @@ def b64(filename):
 
 def upload( buffer, filename, chunksize=4096):
     """
-    upload: save a buffer to a file 
+    upload: save a buffer to a file
     """
     try:
         mkdirs(justpath(filename))
         remove(filename)
         offset = 0
         with open(filename, 'wb') as f:
-            data = buffer[offset:offset+SIZE]
+            data = buffer[offset:offset+chunksize]
             offset+=chunksize
             while data:
                 f.write(data)
-                data = buffer[offset:offset+SIZE]
+                data = buffer[offset:offset+chunksize]
                 offset+=chunksize
             return  True
     except Exception as ex:
+        print(ex)
         return False
